@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_ETMCALENDAR_P_H
-#define AKONADI_ETMCALENDAR_P_H
+#pragma once
 
 #include "calendarbase_p.h"
 #include "calendarmodel_p.h"
@@ -57,7 +56,7 @@ public:
     {
         if (role == Qt::CheckStateRole) {
             // Don't show the checkbox if the collection can't contain incidences
-            const Akonadi::Collection collection = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+            const auto collection = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
             if (isStructuralCollection(collection)) {
                 return QVariant();
             }
@@ -127,4 +126,3 @@ private:
 };
 }
 
-#endif
